@@ -53,26 +53,50 @@ function InstallTools() {
       # Store terminal choice from settings
       terminal=$(cat $2|tr -d '[]"')
 
-      application=$1
+      applicationRun=$1
+      applicationInstall=$1
       # If the application name and the command used to start it are different
       if [ "$1" == "pyakm-manager" ]; then
-            $1="pyakm"
+            applicationInstall="pyakm"
       elif [ "$1" == "pamac-manager" ]; then
-            $1="pamac"
+            applicationInstall="pamac"
       fi
 
-      #This if statement will run the application if installed when $1 != pamac or pyakm
-      if ! $1 ; then
-            if [[ $(yay -Ss $1 --repo | wc -l) -eq 0 ]]; then
+      # If stacer was the application selected, run the below code
+      if [ "$1" == "stacer" ]; then
+            # Install Stacer if necessary
+            if [[ $(which stacer | wc -l) -eq 0 ]]; then
                   $terminal "yay -S $1 --noconfirm"
-            else
-                  pkexec pacman -S $1 --noconfirm
             fi
-      fi
+            # Run Stacer
+            $1 &
 
-      # If (application == pamac || pyakm), then it did not already run in the if statement above.
-      if [ "$1" == "pamac" ] || [ "$1" == "pyakm" ]; then
-            $application
+      # If pace was the application selected, run the below code
+      elif [ "$1" == "pace" ]; then
+            # Install Pace if necessary
+            if [[ $(which pace | wc -l) -eq 0 ]]; then
+                  $terminal "yay -S $1 --noconfirm"
+            fi
+            # Run Pace
+            $1 &
+
+      # If pamac was the application selected, run the below code
+elif [ "$applicationInstall" == "pamac" ]; then
+            # Install Pamac if necessary
+            if [[ $(which pamac | wc -l) -eq 0 ]]; then
+                  $terminal "yay -S $applicationInstall --noconfirm"
+            fi
+            # Run Pamac
+            $applicationRun &
+
+      # If pyakm was the application selected, run the below code
+ elif [ "$applicationInstall" == "pyakm" ]; then
+            # Install Pyakm if necessary
+            if [[ $(which pyakm | wc -l) -eq 0 ]]; then
+                  $terminal "yay -S $applicationInstall --noconfirm"
+            fi
+            # Run Pyakm
+            $applicationRun &
       fi
 }
 
